@@ -72,11 +72,11 @@ class ParameterizingString(text_type):
             # Somebody passed a non-string; I don't feel confident
             # guessing what they were trying to do.
             raise
-        except Exception as err:
+        except curses.error as err:
             # ignore 'tparm() returned NULL', you won't get any styling,
             # even if does_styling is True. This happens on win32 platforms
             # with http://www.lfd.uci.edu/~gohlke/pythonlibs/#curses installed
-            if "tparm() returned NULL" not in err:
+            if "tparm() returned NULL" not in text_type(err):
                 raise
             return NullCallableString()
 
@@ -136,6 +136,9 @@ def get_proxy_string(term, attr):
 
     Returns instance of ParameterizingProxyString or NullCallableString.
     """
+    # normalize 'screen-256color', or 'ansi.sys' to its basic names
+    term_kind = next(iter(_kind for _kind in ('screen', 'ansi',)
+                          if term.kind.startswith(_kind)), term)
     return {
         'screen': {
             # proxy move_x/move_y for 'screen' terminal type.
@@ -151,7 +154,7 @@ def get_proxy_string(term, attr):
             'cnorm': ParameterizingProxyString(
                 (u'\x1b[?25h', lambda *arg: ()), term.normal, attr),
         }
-    }.get(term._kind, {}).get(attr, None)
+    }.get(term_kind, {}).get(attr, None)
 
 
 class FormattingString(text_type):
