@@ -262,7 +262,7 @@ def init_sequence_patterns(term):
     containing sequences generated by this terminal, to determine the
     printable length of a string.
     """
-    if term._kind in _BINTERM_UNSUPPORTED:
+    if term.kind in _BINTERM_UNSUPPORTED:
         warnings.warn(_BINTERM_UNSUPPORTED_MSG)
 
     # Build will_move, a list of terminal capabilities that have
