@@ -15,7 +15,7 @@ import imp
 import os
 
 # local
-from accessories import (
+from .accessories import (
     as_subprocess,
     TestTerminal,
     unicode_cap,
@@ -232,7 +232,7 @@ def test_setupterm_invalid_has_no_styling():
         warnings.filterwarnings("ignore", category=UserWarning)
 
         term = TestTerminal(kind='unknown', force_styling=True)
-        assert term._kind is None
+        assert term.kind is None
         assert term.does_styling is False
         assert term.number_of_colors == 0
         warnings.resetwarnings()
@@ -399,3 +399,57 @@ def test_unknown_preferredencoding_warned_and_fallback_ascii():
                 assert "fallback to ASCII" in str(warned[-1].message)
 
     child()
+
+
+def test_win32_missing_tty_modules(monkeypatch):
+    "Ensure dummy exception is used when io is without UnsupportedOperation."
+    @as_subprocess
+    def child():
+        OLD_STYLE = False
+        try:
+            original_import = getattr(__builtins__, '__import__')
+            OLD_STYLE = True
+        except AttributeError:
+            original_import = __builtins__['__import__']
+
+        tty_modules = ('termios', 'fcntl', 'tty')
+
+        def __import__(name, *args, **kwargs):
+            if name in tty_modules:
+                raise ImportError
+            return original_import(name, *args, **kwargs)
+
+        for module in tty_modules:
+            sys.modules.pop(module, None)
+
+        warnings.filterwarnings("error", category=UserWarning)
+        try:
+            if OLD_STYLE:
+                __builtins__.__import__ = __import__
+            else:
+                __builtins__['__import__'] = __import__
+            try:
+                import blessed.terminal
+                imp.reload(blessed.terminal)
+            except UserWarning:
+                err = sys.exc_info()[1]
+                assert err.args[0] == blessed.terminal.msg_nosupport
+
+            warnings.filterwarnings("ignore", category=UserWarning)
+            import blessed.terminal
+            imp.reload(blessed.terminal)
+            assert blessed.terminal.HAS_TTY is False
+            term = blessed.terminal.Terminal('ansi')
+            assert term.height == 24
+            assert term.width == 80
+
+        finally:
+            if OLD_STYLE:
+                setattr(__builtins__, '__import__', original_import)
+            else:
+                __builtins__['__import__'] = original_import
+            warnings.resetwarnings()
+            import blessed.terminal
+            imp.reload(blessed.terminal)
+
+    child()
