@@ -8,7 +8,7 @@ import platform
 import sys
 import os
 
-from accessories import (
+from .accessories import (
     unsupported_sequence_terminals,
     all_standard_terms,
     as_subprocess,
@@ -119,7 +119,7 @@ def test_unit_binpacked_unittest(unsupported_sequence_terminals):
                                    init_sequence_patterns)
     warnings.filterwarnings("error", category=UserWarning)
     term = mock.Mock()
-    term._kind = unsupported_sequence_terminals
+    term.kind = unsupported_sequence_terminals
 
     try:
         init_sequence_patterns(term)
@@ -221,6 +221,7 @@ def test_inject_move_x_for_screen():
         assert (t.stream.getvalue() == expected_output)
 
     child('screen')
+    child('screen-256color')
 
 
 def test_inject_move_y_for_screen():
@@ -238,6 +239,7 @@ def test_inject_move_y_for_screen():
         assert (t.stream.getvalue() == expected_output)
 
     child('screen')
+    child('screen-256color')
 
 
 def test_inject_civis_and_cnorm_for_ansi():
